@@ -7,20 +7,22 @@
 
 #include <Python.h>
 
+#if (PY_VERSION_HEX < 0x02050000)
+typedef int Py_ssize_t;
+#endif
+
 /* from Crypto++ */
 #ifdef USE_NAME_CRYPTO_PLUS_PLUS
 // for Debian (and Ubuntu, and their many derivatives)
 #include "crypto++/filters.h"
 #include "crypto++/osrng.h"
 #include "crypto++/pssr.h"
-#include "crypto++/randpool.h"
 #include "crypto++/rsa.h"
 #else
 // for upstream Crypto++ library
 #include "cryptopp/filters.h"
 #include "cryptopp/osrng.h"
 #include "cryptopp/pssr.h"
-#include "cryptopp/randpool.h"
 #include "cryptopp/rsa.h"
 #endif
 
@@ -177,7 +179,7 @@ static PyObject *
 SigningKey_sign(SigningKey *self, PyObject *msgobj) {
     const char *msg;
     size_t msgsize;
-    PyString_AsStringAndSize(msgobj, const_cast<char**>(&msg), reinterpret_cast<int*>(&msgsize));
+    PyString_AsStringAndSize(msgobj, const_cast<char**>(&msg), reinterpret_cast<Py_ssize_t*>(&msgsize));
 
     size_t sigsize = self->k->SignatureLength();
     PyStringObject* result = reinterpret_cast<PyStringObject*>(PyString_FromStringAndSize(NULL, sigsize));
